#
# spec file for package strawberry
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           strawberry
Version:        1.0.23
Release:        bp155.2.9.1
Summary:        A music player and music collection organizer
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Sound/Players
URL:            https://www.strawberrymusicplayer.org/
Source:         https://files.strawberrymusicplayer.org/%{name}-%{version}.tar.xz

BuildRequires:  appstream-glib
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
%if 0%{?sle_version} == 150500 || 0%{?sle_version} == 150600
BuildRequires:  gcc13
BuildRequires:  gcc13-c++
%else
BuildRequires:  gcc
BuildRequires:  gcc-c++
%endif
BuildRequires:  gettext
BuildRequires:  git
BuildRequires:  hicolor-icon-theme
BuildRequires:  libboost_headers-devel
BuildRequires:  make
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Qt6Concurrent)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6DBus)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6LinguistTools)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6Sql)
BuildRequires:  cmake(Qt6Test)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-app-1.0)
BuildRequires:  pkgconfig(gstreamer-audio-1.0)
BuildRequires:  pkgconfig(gstreamer-base-1.0)
BuildRequires:  pkgconfig(gstreamer-tag-1.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(icu-uc)
BuildRequires:  pkgconfig(libcdio)
BuildRequires:  pkgconfig(libchromaprint)
BuildRequires:  pkgconfig(libebur128)
BuildRequires:  pkgconfig(libgpod-1.0)
BuildRequires:  pkgconfig(libmtp)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libudf)
BuildRequires:  pkgconfig(protobuf)
BuildRequires:  pkgconfig(sqlite3) >= 3.9
BuildRequires:  pkgconfig(taglib) >= 1.11.1
%if 0%{?suse_version} > 1600
BuildRequires:  cmake(KDSingleApplication-qt6)
%endif

Requires:       qt6-sql-sqlite

%description
Strawberry is a music player and music collection organizer.
It is a fork of Clementine. The name is inspired by the band Strawbs.

Features:
  - Play and organize music
  - Supports WAV, FLAC, WavPack, DSF, DSDIFF, Ogg FLAC, Ogg Vorbis, Ogg Opus, Ogg Speex, MPC, TrueAudio,
    AIFF, MP4, MP3, ASF and Monkey's Audio.
  - Audio CD playback
  - Native desktop notifications
  - Playlists in multiple formats
  - Advanced audio output and device options
  - Edit tags on music files
  - Fetch tags from MusicBrainz
  - Album cover art from Last.fm, Musicbrainz, Discogs, Musixmatch, Deezer, Tidal, Qobuz and Spotify
  - Song lyrics from Lyrics.com, Genius, Musixmatch, ChartLyrics, lyrics.ovh and lololyrics.com
  - Support for multiple backends
  - Audio analyzer
  - Equalizer
  - Transfer music to iPod, MTP or mass-storage USB player
  - Scrobbler with support for Last.fm, Libre.fm and ListenBrainz
  - Subsonic streaming support

%prep
%setup -q

%build
%if 0%{?sle_version} == 150500 || 0%{?sle_version} == 150600
export CC="gcc-13"
export CXX="g++-13"
%endif
export CFLAGS="%{optflags} -fno-strict-aliasing"
export CXXFLAGS="$CFLAGS"
%cmake -DBUILD_WERROR=OFF \
       -DQT_MAJOR_VERSION=6
%cmake_build

%install
%cmake_install

%suse_update_desktop_file org.strawberrymusicplayer.strawberry Qt AudioVideo Audio Player

%check
desktop-file-validate %{buildroot}%{_datadir}/applications/org.strawberrymusicplayer.strawberry.desktop
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/org.strawberrymusicplayer.strawberry.appdata.xml

%files
%doc README.md Changelog
%license COPYING
%{_bindir}/strawberry*
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/*/apps/strawberry.*
%{_datadir}/metainfo/*.appdata.xml
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man1/%{name}-tagreader.1%{?ext_man}

%changelog
* Thu Jan 11 2024 Jonas Kvinge <jonaski@opensuse.org>
- Update to version 1.0.23
  + Bugfixes:
  + Fixed possible duplication of song entries after organizing (#1341).
  + Fixed possible crash when connecting devices (#1313).
  + Fixed playlist sorting of original year (#1349).
  + Enhancements:
  + Treat all stream errors as non-fatal (#1347).
  + Require KDSingleApplication 1.1.0.
  + Fix logging of restored unavailable songs.
* Tue Dec 19 2023 Jonas Kvinge <jonaski@opensuse.org>
- Add BuildRequires for KDSingleApplication-qt6 with Tumbleweed.
* Sat Dec  9 2023 Jonas Kvinge <jonaski@opensuse.org>
- Update to version 1.0.22
  + Bugfixes:
  + Fixed KDSingleApplication cmake version check.
  + Fixed KDSingleApplication Qt 5 detection (#1299).
  + Fixed timer started in wrong thread (#1302).
  + Fixed erratic seeking behaviour if buffer duration is set to zero (#1302).
  + Fixed SCollection related crash on exit with Qt 5 (#1316).
  + Fixed track about to end related crash on playback failure (#1332).
  + Fixed playlist column widths not remembered if stretch mode is off with Qt 6.6.1 and higher (#1328).
  + Enhancements:
  + Increase thread priority for playback threads.
  + Allow drag and drop of songs to favorite playlists.
* Wed Oct 25 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add explicit pkgconfig(fftw3) BuildRequires: This optional
  dependency was previously pulled in by chromaprint. Build moodbar
  support.
* Sat Oct 21 2023 Jonas Kvinge <jonaski@opensuse.org>
- Update to version 1.0.21
  + Bugfixes:
  + Fixed seekbar position resetting to zero before showing actual position when seeking.
  + Fixed compressed files showing up in collection (#1274).
  + Fixed connecting devices (#1288).
  + Fixed device schema missing ebur128 fields.
  + Fixed collection search by tag not working with space between colon and search term (#1290).
  + Fixed seeking when 5 seconds is remaining of the song resetting position to beginning (#1258).
  + Fixed intermittent crash when seeking with Auto as output (#1123).
  + Enhancements:
  + Support using system KDSingleApplication when available.
  + Improved lyrics matching.
* Mon Sep 25 2023 Jonas Kvinge <jonaski@opensuse.org>
- Add libebur128: enabling song playback loudness normalization
* Sun Sep 24 2023 Jonas Kvinge <jonaski@opensuse.org>
- Update to version 1.0.20
  + Fixed appdata validation.
- Update to version 1.0.19
  + Bugfixes:
  + Use shared pointers for objects to fix potential crashes on exit (#1239).
  + Fixed smart playlist search not matching unrated songs (#1244).
  + Fixed reading FMPS_Playcount for MP3 ID3v2 tags (#1248).
  + Always stop playing after 100 errors to prevent flooding the error dialog (#1220).
  + Fixed volume going to 100%% when decreasing volume beyond zero (#1262).
  + Fixed error dialog sometimes showing empty.
  + Enhancements:
  + Add Mpris2 property to read/write rating (#1246).
  + Capitalize playlist column names (#1264).
  + Added lyrics from songlyrics.com, azlyrics.com, elyrics.net and lyricsmode.com.
  + New features:
  + Support performing song loudness analysis using `libebur128` (#1216).
  + Support song playback loudness normalization, as per EBU R 128 (#1216).
  + Other:
  + Removed last.fm HTTPS workaround and GnuTLS dependency
  + Removed broken lyrics.com lyrics provider.
* Sun Sep 17 2023 Jonas Kvinge <jonaski@opensuse.org>
- Rebuild after abseil-cpp update. (boo#1215227)
* Sat Jul  1 2023 Jonas Kvinge <jonaski@opensuse.org>
- Update to version 1.0.18
  + Bugfixes:
  + Fixed reading disc from QObuz songs (#1168).
  + Fixed volume being reset on playback with PulseAudio (#1174).
  + Fixed <br> tags in SQL query error message.
  + Fixed compile with Qt 6 without XCB (QX11Application).
  + Fixed smart playlist editor not properly loading search terms (#1172).
  + Fixed use of fixed icon for playlist favorite star icon (#1178).
  + Possible fix for collection thumbnails using disk cache having identical covers for albums with hashtag (#) in the album title (#1183).
  + Fixed listenbrainz scrobbling for songs with multiple artist mbids.
  + Fixed listenbrainz scrobbling for songs without duration.
  + Fixed gapless playback sometimes not working.
  + Fixed writing PNG images as embedded covers (#1209).
  + Fixed greyscale album covers not working in OSD D-Bus (#1205).
  + Fixed collection thumbnail disk cache with Qt 6.5.1 and newer.
  + Fixed moodbar disk cache with Qt 6.5.1 and newer.
  + Fixed playlist edit tag F2 shortcut only working for title tag (#1210).
  + Append number to filename if the destination file already exist when transcoding audio (#1200).
  + Fixed abseil linking issues with protobuf 1.22.0 and newer.
  + Enhancements:
  + Reduce memory overhead with album cover handling (#1046).
  + Improved listenbrainz error handling.
  + Show error dialog for listenbrainz errors similar to last.fm/libre.fm.
  + Reduce NetworkAccessManager instances.
  + Replace SingleApplication with KDSingleApplication.
  + Require Qt 5.12 or higher.
  + Add new database fields for art_embedded and art_unset.
  + Rewrite album cover loader.
  + Move cover filename settings from collection to covers settings.
  + Add setting to set priorities for album cover types.
  + Add rating filtering to playlist search (#1212).
* Wed Mar 29 2023 Jonas Kvinge <jonaski@opensuse.org>
- Update to version 1.0.17
  + Fixed over-sized context album cover with device pixel ratio higher than 1.0 (#1166).
  + Fixed playing widget fading from a blurry previous cover with device pixel ratio higher than 1.0.
  + Made playlist source icon, album cover manager and OSD pretty cover respect device pixel ratio.
* Mon Mar 27 2023 Jonas Kvinge <jonaski@opensuse.org>
- Update to version 1.0.16
  + Bugfixes:
  + Fixed lyrics from Musixmatch.
  + Fixed possible file corruption when saving both tags and embedded cover using the tag editor (#1158).
  + Fixed compile without GStreamer.
  + Fixed context and playing now album art rendering on High DPI displays (#1161).
  + Fixed setting source properties (device, user-agent, ssl-strict) with GStreamer 1.22 (playbin3) and higher (#1148).
  + Fixed rescan songs feature not ignoring mtime.
  + Search lyrics by artist instead of album artist by default.
  + Code improvements:
  + Replace use of deprecated QSqlDatabase::exec().
  + Added features:
  + Added backend setting for strict SSL mode.
  + Read AcoustID and MusicBrainz tags.
  + Submit MusicBrainz tags with ListenBrainz.
- Remove Qt 5 dependencies
- Remove VLC support
- Update list of lyric providers in features
* Sat Mar  4 2023 Jonas Kvinge <jonaski@opensuse.org>
- Update to version 1.0.15
  + Bugfixes:
  + Fixed playlist column showing invalid last played date for streams.
  + Fixed crash when the audio bin failed to initialize (#1123, #1133).
  + Fixed duplicated filename when organizing files using dot in the filename (#1136).
  + Fixed tag inline editing for streams (#1130).
  + Fixed resetting play statistics using tag edit dialog (#1124).
  + Fixed compilation songs not showing if group by was set to other than (Album) Artist / Album (#1140).
  + Enhancements:
  + Added lyrics from stands4 (lyrics.com).
  + Added Sonogram analyzer.
  + Use GStreamer playbin3 with GStreamer 1.22.0 and higher.
  + Code improvements:
  + Made use of C++11 enum class where possible.
  + Use new QNativeIpcKey based QSharedMemory constructor with Qt 6.6 and higher.
* Fri Jan 13 2023 Jonas Kvinge <jonaski@opensuse.org>
- Update to version 1.0.14
  + Fix initial volume not set when using Auto as output (#1104).
  + Fix saving moodbar if the URL contains host, ie.: UNC paths for SMB (#1101).
  + Fix CollectionBackendTest compile error (#1100).
  + Remove explicitly enabling debug messages (#1106).
* Mon Jan  9 2023 Jonas Kvinge <jonaski@opensuse.org>
- Update to version 1.0.13
  + Fixed volume synchronization leading to infinite loop resulting in crash when adjusting volume while playing (#1089).
  + Fixed incorrect volume.
  + Fixed collection organizing incorrectly handling slashes inside {} brackets for variables (#1091).
  + Fixed saving relative playlists to non-existing playlist files (#1092).
  + Fixed intermittent crash on collection model query (#1095).
  + Require system icons for fancy tabbar and settings sidebar to be larger than 22x22 (#1084).
* Mon Jan  2 2023 Jonas Kvinge <jonaski@opensuse.org>
- Update to version 1.0.12
  + Fixed crash when adjusting volume with mouse wheel (#1089).
  + Fixed playback stopping in certain cases where the next track was unavailable (#958).
  + Removed appearance settings for changing palette colors, it was never properly implemented.
* Fri Dec 30 2022 Jonas Kvinge <jonaski@opensuse.org>
- Update to version 1.0.11
  + Bugfixes:
  + Capitalize GLib application name so it appears nicely in GNOME and PulseAudio Volume Control (#1066).
  + Fixed missing application icon for PulseAudio Volume Control (#1066).
  + Ignore errors for missing albums when updating Tidal collection if there are results (#1061).
  + Only run periodic collection scan when moitoring collection setting is on.
  + Fixed an edge case where the context headline text was being cut short (#1067).
  + Made "Show in file browser" support SpaceFM filemanager (#1073).
  + Fixed incorrect tab order in edit tag dialog (#1075).
  + Changed "FMPS_PlayCount" to "FMPS_Playcount" when saving tag (#1074).
  + Fixed compilation tag read and write for MP4 (#1076).
  + Removed incorrect use of "TPE1" for performer when reading ID3 tags (#1076).
  + Disable tag fields for unsupported tags in tag editor.
  + Don't allow organizing files without unique tags (track or title) for filename (#1077).
  + Don't remove disc from album title when creating cover hash to allow different covers for each disc on an album (#1069).
  + Fixed incorrect relative paths for song filenames when saving playlists if the saved playlist location is a symablic link to the song filename (#1071).
  + Scrobble "Various Artists" as album artist (#1082).
  + Enhancements:
  + Use system volume instead of own software volume when available (#1037).
  + Improved Tidal and Qobuz support with timed requests.
  + Support MPRIS2 xesam:userRating.
* Fri Oct 21 2022 Jonas Kvinge <jonaski@opensuse.org>
- Update to version 1.0.10
  + Bugfixes:
  + Fixed "Could not open settings file for writing: No such file or directory" error before settings file is created.
  + Fixed visual glitch on currently playing track (#1051).
  + Fixed "Unknown error" on Tidal search (#1047).
  + Fixed incomplete lyrics from Genius.
  + Fixed icons not showing in the file view on some systems (#1024).
  + Fixed issues with context and playing widget stopping when using VLC (#1054).
  + Enhancements:
  + Fixed narrowing conversions in connects.
  + Fixed casts from QByteArray.
  + Removed subdir for generated dbus files
  + Removed use of fixed font in context (#1040).
  + Improve Musixmatch lyrics search.
* Sat Sep  3 2022 Jonas Kvinge <jonaski@opensuse.org>
- Update to version 1.0.9
  + Fixed parsing album title from radio stream metadata (#1023).
* Mon Aug 29 2022 Jonas Kvinge <jonaski@opensuse.org>
- Update to version 1.0.8
  + Bugfixes:
  + Fixed backslash being appended to filter text when switching playlist (#1005).
  + Fixed OSD notifications service registering taking too long to timeout when not available.
  + Fixed radio stream added twice when double-clicked (#1015).
  + Fixed translating undo and redo buttons (#1017).
  + Enhancements:
  + Use ICU instead of iconv to transliterate characters for filenames.
  + Make separating albums by grouping tag optional in collection group by album.
  + Added support for video game music formats VGM and SPC.
  + Added setting for explicitly turning on HTTP/2 for streaming. Strawberry will set the libsoup SOUP_FORCE_HTTP1 environment variable when the HTTP/2 is not checked (#1016).
* Mon Jul 25 2022 Jonas Kvinge <jonaski@opensuse.org>
- Update to version 1.0.7
  + Fixed checking file extension case-insensitive when loading and saving playlists.
  + Fixed reading and saving rating with TagParser.
  + Added option for selecting file extension when saving all playlists.
* Sun Jul 17 2022 Jonas Kvinge <jonaski@opensuse.org>
- Build with Qt 6 on openSUSE Leap 15.4 and higher
* Sun Jul 17 2022 Jonas Kvinge <jonaski@opensuse.org>
- Update to version 1.0.6
  + Bugfixes:
  + Fixed certain albums not added to playlist in correct track order from search for Tidal and QObuz.
  + Fixed songs not added to playlist in numeric order when added from file view with right click (#977).
  + Fixed "Stop after this track" graying out next track in dynamic mode (#912).
  + Fixed a gstreamer caps leak when transcoding songs.
  + Fixed errors in translation files (#994).
  + Enhancements
  + Add songs to the collection even when they have invalid ctime or mtime.
  + Made ListenBrainz scrobbler respect "Prefer album artist" option (#989).
  + Send track duration, number, player name and version when scrobbling to ListenBrainz (#995).
* Fri Jun 10 2022 Jonas Kvinge <jonaski@opensuse.org>
- Update to version 1.0.5
  + Bugfixes:
  + Fixed smart playlist filetype search.
  + Fixed Radio Paradise URLs to use HTTPS instead of HTTP.
  + Fixed horizontal scrolling not affecting currently playing track (#952).
  + Fixed keep running in the background when window is closed with Wayland (#964).
  + Fixed percent-encoding of URLs when loading and saving XSPF playlists (#821).
  + Fixed fancy tabbar context menu showing on right clicks outside of tabbar when a song is playing.
  + Fixed possible duplicating songs in the database when moving songs to the collection using the organize feature.
  + Enhancements:
  + Show more details in error dialog on GStreamer errors (#958).
  + Allow setting blur amount of playlist background image up to 100px (#939).
  + Include 128x128 icon sizes (#954).
  + Show right click copy context menu in context view on top text and lyrics (#965).
  + Improve fading between album covers in context view.
  + Added option for overwriting database playcounts in collection settings (#962).
  + Added option for disabling bar on currently playing track (#972).
* Sun Apr 10 2022 Jonas Kvinge <jonaski@opensuse.org>
- Update to version 1.0.4
  + Bugfixes:
  + Fixed use-after-free memory in ALSA PCM device finder.
  + Translate global shortcuts.
  + Enhancement:
  + Added save all playlists action.
  + Other:
  + Removed use of custom font in context.
* Thu Mar 24 2022 Jonas Kvinge <jonaski@opensuse.org>
- Update to version 1.0.3
  + Bugfixes:
  + Remove slash and backslash from filenames when saving album covers using album directory cover filenames (#903).
  + Remove playlist file-extensions from accepted audio file extensions (#909).
  + Fixed Qobuz requests only receiving the first 50 albums (#922).
  + New features
  + Added support for bs2b (Improved headphone listening of stereo audio records using Bauer stereophonic-to-binaural DSP) (#249).
* Mon Mar  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Increase the disk size needed to build strawberry on PowerPC.
- Remove the unneeded qt6-network-tls requirement.
  libQt6Network6 already requires the plugin.
* Sun Feb 20 2022 Jonas Kvinge <jonaski@opensuse.org>
- Update to version 1.0.2
  + Bugfixes:
  + Fixed showing menu when clicking icon for collection and internet search tool buttons
  + Fixed ignoring devices with system mounts as defined by GIO (#410).
  + Fixed updating database when deleting songs from filesystem devices.
  + Fixed unregistered metatype when listing songs from MTP devices with Qt 6.
  + Fixed using entered password when testing Subsonic settings before pressing save (#879).
  + Fixed downloading Subsonic album covers.
  + Fixed subsonic album covers downloaded several times for each album when MD5 authentication was enabled (#885).
  + Fixed volume going to 100%% when pressing volume down with MRPIS2 and global shortcuts (#884).
  + Fixed incorrect rounding when setting volume through MPRIS2 (#894).
  + Fixed delete from disk not showing up in the menu when one or more CUE songs were selected.
  + Fixed possible crashes when switching songs when fading is enabled (#890).
  + Fixed X11 global shortcuts not working unless window was in focus with Qt 6.2 and higher (#893).
  + Fixed scrobbler re-sending scrobbles to fast on error (#898).
  + Enhancements
  + Log Qt version on startup.
  + Added button for deleting existing Subsonic songs (#883).
  + Make collection watcher ignore files with "qt_temp" filename and tmp extension.
  + Require Qt 5.9 or higher.
  + Added scrollbars to edit tag dialog (#888).
  + Added advanced settings for configuring collection watcher.
  + Disable open audio CD menu when compiled without audio CD support.
  + Replaced use of deprecated QMouseEvent constructor as of Qt 6.4.
  + Replaced use of deprecated QCryptographicHash::addData overload as of Qt 6.4.
  + Removed features:
  + Removed broken "nomedia" / "nomusic" file handling.
* Sat Jan  8 2022 Jonas Kvinge <jonaski@opensuse.org>
- Update to version 1.0.1
  + Bugfixes:
  + Fixed collection and internet search filter tool button menu arrow overlap (#796).
  + Fixed stop after this track button with Qt 6 (#795).
  + Fixed not updating the URL when songs were moved on disk when the fingerprinting feature is enabled.
  + Fixed SQL query error for songs with an invalid modification time (#815).
  + Fixed blocky rendering of the currently playing track with high resolution screens (#794).
  + Fixed incorrect playlist column filesize for radio streams.
  + Fixed deleting embedded album cover from Ogg songs.
  + Fixed parsing of Cue tracks with 1-digit minutes (#836).
  + Fixed updating of playlist summary after reloading items when adding songs from files outside of the collection (#848).
  + Fixed always saving metadata when saving playlists for Tidal, Qobuz and Subsonic songs independent of playlist setting (#851).
  + Fixed setting media shortcuts when using kglobalaccel (#849).
  + Fixed parsing of Genius lyrics when they are sometimes received in a different HTML format.
  + Fixed saving MP4 specific tags as UTF-8 (#830).
  + Fixed clearing "manually set" cover when saving album covers embedded from outside of the tag editor (#858).
  + Fixed aborting collection scan when Strawberry exists to avoid hang on exit.
  + Fixed resuming collection scan when adding a new directory after collection scan was aborted.
  + Fixed excluding hidden songs from the collection.
  + Disabled moodbar for CUE songs since they can not be supported properly (#865).
  + Enhancements:
  + Made playlist header column text elided (#801).
  + Added support for reading and writing playcounts and ratings from/to tags.
  + Added support for setting rating using the edit tag dialog.
  + Added setting to enable/disable playlist toolbar (#809).
  + Added component type, content_rating type and releases to AppStream data file (#806).
  + Removed unused "mark as listened" option in organize dialog.
  + Fixed some clazy warnings and narrowing conversions in the source code.
  + Replaced uses of macros in the source code.
  + Added a more user-friendly error message when receiving encrypted streams from Tidal (#824).
  + Added support for port-pattern entered in the device textbox when using Jack as output (#828).
  + Added Spanish (Spain) translation.
  + Added support for more CUE filenames (#835).
* Thu Oct 14 2021 Jonas Kvinge <jonaski@opensuse.org>
- Update to version 1.0.0
  + Bugfixes:
  + Fix updating temporary metadata when reloading songs outside of the collection.
  + Don't strip off "Live" from song title when sending scrobbles.
  + Fix incorrect use of QFutureWatcher.
  + Fix compile of Utilities::Hmac with Qt 6.2.
  + Fix a memory leak when using right click context menu in internet search.
  + Fix a gstreamer bus leak when adding streams and remote playlists.
  + Fix "Source ID x was not found when attempting to remove it" error.
  + Escape ampersands in playlist tabs.
  + Fix analyzer with S24_32LE audio format.
  + Enhancements:
  + Add replaygain fallback gain setting.
  + Add option to turn off playlist alternating row colors.
  + Make the default tabbbar background color lighter.
  + Remove use of deprecated WinExtras Qt module.
  + Add CMake test for Qt sqlite support.
  + Automatically detect Qt version if BUILD_WITH_QT5 or BUILD_WITH_QT6 is not specified.
  + Correct playlist tabbar favorite tooltip from "click" to "double-click".
  + Remove scroll over icon to change track option since it does not work reliable.
  + Improve resume playback on startup.
  + Re-request stream URL for Tidal and QObuz when resuming playback after pausing for more than 30 seconds.
  + Add Finnish, Ukrainian, Dutch, Japanese, Chinese, Catalan and Portuguese (Brazil).
  + Add support for TagParser (https://github.com/Martchus/tagparser) as an alternative to TagLib.
  + Add Subsonic option to turn off HTTP/2.
  + Fix minor Clang-Tidy and Clazy warnings.
  + Use higher resolution images from last.fm API.
  + Add MD5 token authentication for Subsonic.
  + Use 500 albums per request when receiving albums from Subsonic.
  + Use QX11Application with Qt >= 6.2 for X11 global shortcuts.
  + Allow fading when a ALSA PCM device is selected.
  + Store Tidal MPEG-DASH file in data uri.
  + Use XSPF image elements as manually set artwork.
  + Make error dialog larger.
  + Show error dialog for failed SQL queries.
  + Show error dialog when failing to read or write album covers.
  + Add module music formats (mod, s3m, xm, it) to detected filetypes.
  + Disable gapless playback for module music formats to workaround gstreamer bug.
  + Update directory ID and song path immediately when organizing collection songs.
  + Add right click option to star a playlist in playlist tabs.
  + Use seconds instead of minutes for scrobble submit delay.
  + New features:
  + Add ALSA PCM devices.
  + Add song fingerprinting and tracking.
  + Add support for native global shortcuts on MATE.
  + Add radios view with channels from Radio Paradise and SomaFM.
* Sun Apr 18 2021 Jonas Kvinge <jonaski@opensuse.org>
-Update to version 0.9.3:
  + Bugfixes:
  + Fix "Show in file browser" to work with thunar.
  + Check that the clicked rating position is to the right or left of the rectangle.
  + Fix rescan when collection directory is removed and readded.
  + Enhancements:
  + Allow editing playlist metadata for radio streams.
  + Make CollectionQuery subclass QSqlQuery, avoid copying QSqlQuery.
  + Only enable FTS3 when schema needs upgrading, since FTS5 is used for search.
  + Add setting for configuring the color for the currently playing song.
  + Add setting to turn on OSD Pretty fading.
  + Add commandline option to resize window.
* Thu Mar 25 2021 Jonas Kvinge <jonaski@opensuse.org>
- Update to version 0.9.2:
  +  Fix marking songs available.
  +  Fix crash when transcoding music, or copying music to devices with transcoding.
  +  Fix copying album covers to iPod.
  +  Fix playlist tabbar close and save right click actions.
  +  Fix slow opening of cover manager.
* Sat Mar 13 2021 Jonas Kvinge <jonaski@opensuse.org>
- Update to version 0.9.1:
  + Bugfixes:
  + Fix duplicating songs in the DB when organizing songs between 2 different collection directories.
  + Fix overwriting existing newer last played when importing last played from last.fm.
  + Fix memory leak on song change when moodbar is disabled.
  + Fix playlist filter search for text with spaces with Qt 6.
  + Fix 'Except between tracks on the same album' backend fade option always greyed out.
  + Fix read and save vorbis comment grouping tag.
  + Fix QAtomicInteger compile error on armv.
  + Fix compile error with protobuf 3.15.0 and newer.
  + Fix possible tagreader (messagereply) crashes.
  + Fix save album cover when album directory and no overwrite is used for saving covers.
  + Fix right click save cover action when album has embedded cover.
  + Fix temporary art saved to /tmp.
  + Fix playlist bitrate sometimes stuck when changing track to previous.
  + Enhancements:
  + Improve Musixmatch cover and lyrics search.
  + Decode any HTML entities in some rare cases they appear in the retrieved lyrics from the API's.
  + Use mimetype instead of description from stream metadata by default when updating song filetype.
  + Set limits for collection pixmap cache based on size units.
  + Convert all signal/slot connections to new Qt 5/6 syntax.
  + Improve album cover management.
  + Add right click actions to clear set cover, and option delete covers.
  + Show artist and album underneath the albums in the cover manager when all Artists is selected.
  + Disable unavailable right click cover actions.
  + Remove 3rdparty TagLib now that TagLib 1.12 is available.
  + New features:
  + Add option and support for saving embedded covers for FLAC, Ogg Vorbis, MP3 and MP4/AAC.
- Remove use of deprecated USE_SYSTEM_TAGLIB CMake option.
* Wed Dec 23 2020 Jonas Kvinge <jonaski@opensuse.org>
- Use cmake_build macro
- Use Qt 6 on tumbleweed
* Sat Dec 19 2020 Jonas Kvinge <jonas@jkvinge.net>
- Update to version 0.8.5:
  * Bugfixes:
  + Fix return type of SmartPlaylistQueryWizardPlugin::type().
  + Fix comparison between QChar and integer to use QChar::unicode().
  + Fix return type of qHash with Qt 6 to use size_t instead of uint.
  + Fix tag edit dialog save process sometimes stuck.
  + Fix repeat and shuffle buttons greyed out when a dynamic playlist is open.
  + Fix CUE parser handling of values with empty quotes.
  + Fix broken year and disc collection groupings with CUE songs.
  + Fix HTML escaping showing up in OSD notifications when using custom text.
  * Enhancements:
  + Add Swedish translation.
  + Made Qt X11Extras and WinExtras modules optional.
  + Save and restore geometry in edit tag dialog.
  + Add command line option to play a playlist based on name.
  + Change double-click behaviour in cover manager to open fullsize cover.
* Sat Nov 14 2020 Jonas Kvinge <jonas@jkvinge.net>
- Update to version 0.8.4:
  * Bugfixes:
  + Fix preventing session logout when window is maxmimized.
  + Fix empty space in organize window when copying songs/playlists to devices.
  + Fix crash when opening about dialog in a wayland session.
  + Fix stretched fancy/side tabbar style issue with adwaita style (Fedora/Gnome).
  + Fix centering star icon on playlist tabbar.
  + Fix network proxy settings for streaming.
  + Fix copy URL to clipboard to handle non-ASCII characters.
  + Fix HiDPI scaling for glow animation and drag over playlist.
  + Fix smart playlist search by filename.
  + Fix single letter collection nodes showing before dividers.
  * Enhancements:
  + Add support for native global shortcuts on KDE.
  + Add track progress in system tray icon as an option.
  + Only strip problematic characters in suggested filename when saving a playlist to file.
  + Change star/unstar playlist to doubleclick instead of singleclick.
  + Don't edit playlist name on doubleclick in playlists view.
  + Make context view top label text selectable.
  + Add setting to change Qt style.
  + Clear ID3v3 tags that are empty, and clear ID3v1 tags when setting ID3v3 tags.
  + Remove remaining uses of QTextCodec.
  + Remove Core5Compat dependency.
* Fri Oct 23 2020 Jonas Kvinge <jonas@jkvinge.net>
- Update to version 0.8.3:
  + Fixed updating playing widget song details in small cover mode.
  + Fixed file extension when transcoding songs.
  + Fixed updating album cover to collection in edit tag dialog when pressing save.
  + Fixed songs with empty artist in collection.
  + Fixed possible crashes with stream discovery.
  + Fixed setting engine state to null.
  + Fixed tagreader crash with empty APE tags.
  + Fixed a gstreamer memory leak.
* Tue Oct 13 2020 Jonas Kvinge <jonas@jkvinge.net>
- Update to version 0.8.2:
  * Bugfixes:
  + Fixed broken transition to next song for CUE files with certain audio formats (regression since version 0.6.13).
  + Fixed all collection divider keys showing on top with some language collate settings (regression in version 0.8.1).
  + Fixed SQL querying songs by song ID when song ID is a string.
  + Fixed saving album covers for LMS Subsonic servers.
  + Fixed reading song creation dates with LMS Subsonic servers.
  + Fixed saving initial settings.
  + Removed use of HTML in system tray icon tooltip for all desktop environments instead of just KDE and Cinnamon.
* Fri Oct  9 2020 Jonas Kvinge <jonas@jkvinge.net>
- Update to version 0.8.1:
  * Bugfixes:
  + Fixed engine selection in backend settings with Qt 6.
  + Fixed pixelated playlist source icon for currently playing song.
  + Fixed crash when deleting queued songs from playlist.
  + Fixed situations where songs could disappear or be shown multiple times with certain collection groupings.
  + Fixed initial sizes of playlist header columns.
  + Fixed Strawberry preventing logout.
  + Fixed incorrectly splitting of basename for moodbar and transcoding for filenames with several dots.
  + Fixed certain cases where "playing now" for scrobbler were sent twice.
  + Fixed album cover loaded twice for certain songs causing slugglish playing widget.
  + Fixed playing widget to draw text after album cover is fully shown.
  + Fixed crash when trying to copy a closed playlist to a device.
  + Fixed incorrect song source for CUE songs when added through the collection watcher.
  + Disable use of HTML in system tray tooltip on Cinnamon too.
  + Remove problematic '&' character from OSD messages.
  * Enhancements:
  + Improved playlist autoscrolling.
  + Only allow playlist right click tag editing for editable songs.
  + Read song creation time from subsonic API.
  + Remember manually set compilation status for albums when songs are rescanned.
  + Added icons for edit tag playlist right click menu actions.
  + Maximize dialogs if they are already open when clicked again in the menu.
  + Added support for compilation tag to edit tag dialog.
  + Show song info and album cover in OSD on stop and pause.
  + Reshow OSD on song restart.
  + Always save initial settings.
  + Removed use of deprecated gstreamer "low-percent" (Minimum buffer fill setting).
  + Added buffer low and high watermark settings to backend settings.
  + Make use of newer version of the desktop notifications service when available.
  * New features:
  + Added setting for enabling scrobbling based on song source.
  + Added optional delete from disk in collection and playlist.
  + Added Last.fm import data wizard.
  + Added smart and dynamic playlists.
  + Added song ratings.
  + Added Qobuz streaming support.
  + Added Subsonic server side scrobbling support.
  + Load thumbnails from iPods to show under device collection.
* Sat Aug 15 2020 Jonas Kvinge <jonas@jkvinge.net>
- Update to version 0.7.2:
  * Bugfixes:
  + Fixed installation directory for translations.
  + Fixed collection sorting for non-ASCII characters.
  + Fixed closing connected devices on exit.
* Fri Aug 14 2020 Jonas Kvinge <jonas@jkvinge.net>
- Update to version 0.7.1:
  * Bugfixes:
  + Fixed incorrectly mapped global shortcuts keys "2" and "3".
  + Fixed Last.fm scrobbling to correctly start array notation for parameters at 0 and not 1.
  + Fixed sending trackNumber correctly for Last.fm and Libre.fm scrobbling.
  + Fixed collection search when using special characters in the search query.
  + Fixed reading and saving MP4 lyrics tag.
  + Fixed reading ASF comment tag.
  + Fixed adding playlist songs outside the collection when there are multiple files with the same URL.
  + Fixed the rescan songs option to work with local songs outside of the collection.
  + Fixed problems with editing song metadata in the playlists.
  * Enhancements:
  + Simplified and improved startup behaviour code.
  + Adapted all source code to be compatible with Qt 6, and increased required Qt version to 5.8.
  + Added option to compile with Qt 6 (-DWITH_QT6=ON).
  + Base warning for show in file browser on unique directories to avoid unneeded warning about opening many files.
  + Use album artist instead of artist for album repeat mode when available.
  + Added extra safety for overwriting files for filesystem storages when organizing files.
  + Remove diacritics in FTS search.
  + Improved playlist context menu.
  + Added fatal CMake error for missing protobuf compiler.
  + Added support for parsing radio streams metadata with tilde in title.
  + Added CMake option to install translation files.
  + (Unix) Added playback actions to desktop file.
  * Removed features:
  + Removed Xine engine support.
  + Removed broken imobiledevice (iPhone) support.
* Mon Jul 20 2020 Michel Normand <normand@linux.vnet.ibm.com>
- Add _constraints for ppc64le avoid "no space left on device" build error
* Mon Jul 13 2020 Jonas Kvinge <jonas@jkvinge.net>
- Update to version 0.6.13:
  * Bugfixes:
  + Fixed cut-off text in about dialog.
  + Fixed increasing play count when stop after track is enabled.
  + Fixed showing/hiding playing widget when playback is started while window is hidden.
  + Fixed "Show in file browser" to also work on local songs that are not in the collection.
  + Fixed "Show in file browser" to work with PCManFM file manager.
  + Fixed audio analyzer to work with S24LE and F32LE audio formats.
  + Fixed playlist background image not loading.
  + Fixed a memory leak when switching between playlists.
  + Removed use of HTML in systemtray tooltip on KDE, since KDE no longer renders HTML in the systemtray.
  * Enhancements:
  + Replaced use of C style casts.
  + Adapted use of C++11 override.
  + Improved CMake build files.
  + Added new on startup options to show maximized or minimized.
  + Builtin TagLib code is updated and improved.
  + Made most icon sizes configurable in the settings, and increased default sizes for icons.
  + Improved fancy tabbar to use font sizes from the theme instead of fixed sizes.
  + Moving the currently playing song to the top when the playlist is manually shuffled.
  + Added "a taste of Strawbs" background image.
  + Fixed unit test for testing playlist model.
  + Added new unit tests for tagreader.
* Sun Jun  7 2020 Jonas Kvinge <jonas@jkvinge.net>
- Update to version 0.6.12:
  * Bugfixes:
  + Fixed height of about dialog.
  * Enhancements:
  + Only save settings for pages that actually has been changed.
  + Replaced use of deprecated Qt functionality as of 5.15.
  + Made scrobbler show error dialog for all errors when show error dialog option is on.
  + Dont append disc to album titles for Subsonic and Tidal.
  + Sort folders added from file view.
  + Changed default collection grouping to album - disc.
* Sat May 16 2020 Jonas Kvinge <jonas@jkvinge.net>
- Update to version 0.6.11:
  * Bugfixes:
  + Fixed MPRIS missing art url when playing albums with embedded cover.
  + Fixed updating local non collection songs when manually unsetting cover.
  + Fixed infinite loop and preceding crash when CSS background-color was set in qt5ct.
  + Fixed UI freeze when updating the database from a large Subsonic or Tidal collection.
  + Fixed crash when CD loading fails in devices.
  + Fixed CD devices showing up with having 0 songs after loading.
  + Fixed the album cover loading indicator being stuck if no cover providers were available.
  + Fixed the playing widget not updating artist, album or title after metadata has changed for a song when no album cover was loaded.
  * Enhancements:
  + Sort songs in collection by song title instead of track if previous grouping is not the album.
  + Added option to switch on/off automatically searching for album covers to context settings.
  + Reset last played song when playlist is finished.
  + Checking content type of received HTTP request for image when receiving album covers.
  + Added option to scrobbler setting for turning off login error popup.
  + Made MusicBrainz and Discogs cover providers respect rate limiting.
  * New features:
  + Added option to show/hide sidebar.
  + Added settings for selecting album cover and lyrics providers.
  + Added album covers from Musixmatch and Spotify.
  + Added lyrics from Genius, Musixmatch and ChartLyrics.
* Fri May  1 2020 Jonas Kvinge <jonas@jkvinge.net>
- Update to version 0.6.10:
  * Bugfixes:
  + Fixed Subsonic album covers not working for albums with non ASCII charcters.
  + Fixed reading date and genre from individual tracks in CUE sheets.
  + Fixed resume playback on startup for CUE songs.
  + Fixed album cover manager not showing complete album titles in the list of album covers.
  + Fixed save album cover to file saving "no cover" image instead of actual album cover.
  + Fixed device state text color in devices not being visible when using a dark theme.
  + Fixed engine and device in context using too large icons when icons were loaded from the system theme.
  + Fixed "Secure connection setup failed" problem on Windows when playing streams.
  + Fixed margin for song title text in context.
  + Fixed UNC paths with non ASCII charcters not working.
  * Enhancements:
  + Allowing all characters except slash and backslash when organising music unless options to strip characters is checked.
  + New option in organising music to remove problematic filename characters that removes less characters than the FAT option.
  + General improvements to the album cover loader and album cover providers code.
  + Fixed loading album cover images from album directory for songs added to the playlist from outside of the collection.
  + Made automatic album cover search work for songs outside of the collection and for streams.
  + Made album cover search work based on artist + title if album title is not present for providers supporting song/track search.
  + Update art manual in playlist for local files, devices and CDDA to avoid loading covers multiple times.
  + Made lyrics search work for streams.
  + Added "add stream" to menu.
  + Only showing song length in context when available.
  + Sort album cover search results by score and pick the best 3 first before trying others to improve album cover search speed.
  + Make scrobbler work for streams.
  + Added search for lyrics as a seperate option in context.
  + Made font and font sizes in context configurable.
  + Splitting artist and song title to the relevant metadata when artist and song title is sent as title seperated by a dash in streams.
  + Added label to show collection pixmap disk cache used in settings.
  + Icreased default collection pixmap disk cache to 360.
  * New features:
  + Added back Tidal streaming support.
  + Added Qobuz album cover provider.
  * Removed features:
  + Removed Phonon engine support.
* Thu Apr  9 2020 Jonas Kvinge <jonas@jkvinge.net>
- Update to version 0.6.9
  * BugFixes:
  + Fixed playlist metadata updating interfering with manual tag editing.
  + Fixed order of tabs in all windows.
  + Fixed playlist right click using wrong songs for determining menu options when playlist was filtered.
  + Fixed possible crashes on playlist right click.
  + Fixed possible null pointer crash in OSD pretty.
  + Fixed track and title in playlist not being movable.
  + Fixed Subsonic support to handle numeric Json values like track and disc both as strings and integers.
  + Fixed Subsonic compatibility with LMS (Lightweight Music Server).
  + Disabled "open Audio CD" from menu on Windows where CD support is currently not supported.
  + Fixed files containing "MAC" being detected as Monkey's Audio.
  * Enhancements:
  + Improved support for High DPI displays.
  + Added CMake check for backtrace() to fix compilation with musl libc.
  + Made album cover in context adjust to width.
  + Made settings, cover manager, organise dialog and transcode music dialog center on the same display where the mainwindow is located.
  + Removing empty directories when organizing music.
  + Made file selection work in "Show file in browser" for Dolphin and Nautilus.
  + Implemented disk caching of album thumbnails in collection tree.
  + Use a shorter playlist name when songs are added from file view.
  + Disabled optical drives in copy to device menu.
  + Added better error handling for CDDA loading.
  + Added Polish, Hungarian and Korean translations.
  * Removed features:
  + Chartlyrics support (Unstable API).
  + Tidal support (No agreement).
  + QObuz support (No agreement).
* Thu Feb 20 2020 Markus S <kamikazow@opensuse.org>
- Clean up strawberry.spec file by removing conditions for EOL Leap 42.x.
* Sun Jan  5 2020 Jonas Kvinge <jonas@jkvinge.net>
- Update to version 0.6.8
  + Fixed stuck tabbar and collection GUI with some themes.
  + Fixed possible crashes related to QProxyStyle.
  + Fixed a bug where metadata in the playlist was not updated when editing metadata for the current playing track.
  + Fixed crash when deleting a folder with playlists.
  + Fixed restoring to correct screen when maximized.
  + Increased lyrics score if lyrics text is larger than 60 characters to avoid using "no lyrics available" text.
  + Made context title and summary changeable.
  + Added option to disable playlist clear button.
  + Added confirmation dialog before clearing playlists with more than 500 songs.
  + Added German, French, Italian and Indonesian translations.
  + Added StartupWMClass to desktop file.
  + Replaced use of Qt deprecated functionality as of 5.14.
* Wed Nov 27 2019 Jonas Kvinge <jonas@jkvinge.net>
- Update to version 0.6.7
  + Fixed crash when cancelling scrobbler authentication
  + Fixed "Double clicking a song in the playlist" behaviour setting
  + Fixed "Pressing Previous in player" behaviour setting
  + Fixed updating compilations where there are spaces or special characters in filenames
  + Fixed cases where songs were stuck in "Various Artists" because not all songs in
  the same compilation was removed from the model before readded with actual artist.
  + Fixed a bug when importing playlists where metadata was reset
  + Fixed scrobbler to also scrobble songs without album title
  + Fixed text for replay gain setting not loading in backend setting
  + Added back lyrics from Chartlyrics
  + Added ability to show fullsize cover on double-click in playing widget
  + Added separator between "unset cover" and "show fullsize" in popup menu
  + Removed left click on analyzer to popup menu
  + (Windows) Added killproc executable to terminate running process before uninstalling
* Sat Nov  9 2019 Jonas Kvinge <jonas@jkvinge.net>
- Update to version 0.6.6
  + Fixed lowercased album artist in playlist column
  + Fixed compiling with different optional features turned off
  + Fixed hang in stream discoverer with certain formats
  + Fixed Subsonic to correctly read disc
  + Fixed preventing system logoff or shutdown
  + Fixed correctly updating compilations
  + Simplified gstreamer pipeline code
  + Disabled showing analyzer for bit depths not supported by the analyzer
  + Made stereo balancer independent from equalizer
  + Added option to prefer album artist when sending scrobbles
  + Removed lines in settings
  + Added limit for number of tagreader processes to 2
  + Improved system theme icon option to better pick correct icons
  + Added option to automatically select current playing track
  + (Windows) Added support for WASAPI
* Mon Sep 30 2019 Jonas Kvinge <jonas@jkvinge.net>
- Update to version 0.6.5
  + Fixed scrobbler not to send scrobbles multiple times when metadata is updated
  + Fixed Listenbrainz scrobbler not to send "various artists" as album artist
  + Fixed missing cover image in OSD pretty reposition image
  + Fixed OSD pretty upper left positioning
  + Fixed OSD pretty positioning on Windows on screens with negative geometry
  + Fixed appdata file to pass full validation
* Wed Sep 25 2019 Jonas Kvinge <jonas@jkvinge.net>
- Update to version 0.6.4
  + Added setting for fancy tabbar background color
  + Added setting to make marking songs unavailable optional
  + Added lyrics from lyrics.ovh and lololyrics.com
  + Fixed so that Subsonic verify certificate setting takes affect immediately
  + Fixed all services to follow redirects
  + Fixed so that songs with different albums are not treated as duplicates
  + Fixed SingleApplication to use native system calls on Linux for getting username
  + Added stream discoverer to gstreamer pipeline to detect stream filetype, samplerate and bit depth
  + Disabled video in gstreamer pipeline
  + Fixed ampache compatibility
  + Fixed lyrics searcher not to try search for lyrics with empty song artist or title
  + Fixed Qobuz login to send mac address as device manufacturer id on login
  + Fixed Qobuz invalid signature parameter error when retrieving stream urls
  + Fixed player not using preloaded stream url causing gapless playback to break
  + Increased preload gap for gstreamer to make sure gapless playback works better
  + Fixed setting and resetting temporary metadata for next playlist item
  + Replaced media buttons with more correct ones
  + Fixed windows thumbbar
  + Lowered required Subsonic API version to 1.11.0
  + Fixed Subsonic to allow empty artist and album in song replies
  + Added Russian translations
  + Fixed some services API urls using http to use https
  + Fixed restoring to original window size when restoring from system tray
  + Updated 3rdparty taglib
- Update URLs
- Update summary and description
* Mon Aug  5 2019 Jonas Kvinge <jonas@jkvinge.net>
- Update to version 0.6.3
  + Fixed crash when using internet services.
  + Fixed musicbrainz tagfetcher only showing 1 result per song.
  + Fixed collection watcher to unwatch deleted directories.
  + Added "album - disc" grouping.
* Sat Aug  3 2019 Jonas Kvinge <jonas@jkvinge.net>
- Update to version 0.6.2
  + Disabled fatal error for FTS5 cmake test.
* Sat Aug  3 2019 Jonas Kvinge <jonas@jkvinge.net>
- Update to version 0.6.1
  + Compare artist and album case-insensitive when generating score for album covers.
  + Fixed broken return value of sendMessage() in SingleApplication causing application to be started twice.
  + Improved error handling in local redirectserver.
  + Added new tabs view with search and favorites to Tidal.
  + Fixed gst_pad_send_event lock in gstreamer pipeline.
  + Made Xine analyzer optional to fix compilation with newer Xine.
  + Implemented offset and queue to all Tidal requests.
  + Added new artist, album and song ids to songs schemas to add/remove favorites.
  + Improved lyrics searcher.
  + Fixed disabling fading option in backend settings when volume control is disabled.
  + Added x-scheme-handler/tidal to desktop file to handle tidal songs and allow OAuth redirect url.
  + Added love button for scrobblers.
  + Fixed gapless playback when using url handler.
  + Fixed enabling/disabling fading options in backend settings.
  + Added support for Subsonic streaming.
  + Added support for Qobuz streaming.
  + Added confirmation box for opening songs in file browser to avoid users accidentally opening too many songs.
  + Added OSD notification on playback resume option.
  + Fixed MusicBrainz tag fetcher to respect rate limiting when fetching tags.
  + Fixed hardcoded systemtray icon.
  + Added live scanning and option to rescan songs.
  + Added playlist background image stretch option to zoom image with cutting the height.
  + Replaced use of QDesktopWidget with QDesktop
  + Replaced all uses of QSignalMapper with lambda expressions
  + Fixed collection album covers stuck to old ones when new album covers are fetched
  + Fixed all Json services to check HttpStatusCodeAttribute in addition to checking network errors
  + Fixed track change hang
  + Fixed playlist sorting to ignore articles
  + Fixed MessageReply crash in tagreader
  + Fixed MTP support
  + Fixed possible crashes with libimobiledevice devices
  + Removed older devicekit udisks backend
  + Using iconv to replace non-ascii characters when organising files
  + Fixed IPod support when listed from UDisks2
  + Fixed memory leaks when establishing database connections and in database backup.
  + Fixed dangling database connections when loading collection, playlists and devices.
  + Fixed closing and deleting backends to free memory and database connections on exit.
  + Fixed dangling pointers causing crashes when loading new album covers in collection.
  + Fixed playlist shortcuts being broken because they were hidden in playlist right click menu.
  + Replaced FTS3 and custom tokenizer with FTS5 with unicode61.
  + Fixed certain cases where track slider popup was stuck.
  + Fixed certain cases where the playing widget gets stuck when switching fast between context and other widgets.
  + Removed ChartLyrics provider (service have been down for a long time).
* Sun May  5 2019 Jonas Kvinge <jonas@jkvinge.net>
- Update to version 0.5.5
  + Fixed Tidal API url
* Sun May  5 2019 Jonas Kvinge <jonas@jkvinge.net>
- Update to version 0.5.4
  + Changed description for offline mode scrobbling for less confusion
  + Fixed scrobbler to not send "playing now" when in offline mode
  + Added common RPM spec file for openSUSE, Fedora, RedHat, CentOS and Mageia
  + Improved cover manager score system
  + Added Deezer and Tidal cover providers
  + Added ChartLyrics lyrics provider
  + Added HTTPS workaround for Last.Fm OAuth to solve redirect https to http (localhost) problems
  + Added Moodbar
  + Fixed incorrect desktop file returned by mpris2
  + Fixed mpris2 CanPlay
  + Fixed updating play and skip count properly
  + Fixed track seeking with mouse wheel
  + Fixed CDDA tracks being invalidated (greyed) in the playlist
  + Fixed problems using transcoder when other engines were selected
  + Improved song loader error handling
  + Fixed enabling equalizer having no affect
  + Disable notification art setting when tray icon notification is selected
  + Applying settings immediately when pressing Apply in settings dialog instead of just saving
  + Disable scroll over icon to change track setting on non-X11 systems and KDE
  + Removed nvidia workaround on exit which is no longer needed
  + Fixed chromaprinter unref buffer crash when using complete tags automatically
  + Fixed crash on exit using VLC engine when using static taglib caused by tagblib linking collision
  + Fixed context background to follow base colors instead of always white
  + Fixed fancy tabbar small sidebar mode width
  + Added some missing taglib configure checks
  + Saving geometry, tabbar, playlist column settings on exit only to reduce wear on SSD's and fix sluggish resizing with non-SSD
  + Fixed and improved snap including upgrading to core18 and adding proper alsa support
  + Fixed resume playback on startup not working for other than the first playlist
* Mon Apr  1 2019 Jonas Kvinge <jonas@jkvinge.net>
- Update to version 0.5.3
  + Changed default tagging to albumartist in organise dialog
  + Removed support for older taglib in tagreader
  + Made lyrics selectable in context
  + Added boom and rainbow analyzers
  + Made it possible to use enter in shortcuts
  + Replaced "no album cover" image
  + Capitalized Strawberry in OSD and tooltip
  + Added artist search to Tidal
  + Created systray tooltip workaround for KDE
  + Changed defaults for backend fade setting
  + Changed backend settings to allow setting device back to automatic when a custom device is active
  + Hide ALSA options on non-ALSA systems
  + Showing errors in dialog when editing tags fails
  + Update database immediately when saving tags were successful
  + Show Strawberry icon in OSD when stopping track
  + Added support for translations
  + Renamed desktop and appdata files to follow freedesktop specifications
  + No longer allowing X11 shortcuts on Wayland
  + Fixed handling of UNC paths in gstreamer engine
  + Added option to disable volume control
  + Removed Deezer support (SDK discontinued and streams are encrypted)
  + Added Norwegian and Spanish translations
  + Added setting to allow automatically saving album covers directly to album directory
  + Updated mimetypes
  + Added basic support for system and custom icons
  + Moved loading of device icons to device model
  + Added better support for APE tags
  + Fixed problems identifying song as collection songs when loading playlist files
  + Fixed problems loading Tidal URLs from playlist files
  + Added support for saving and restoring geometry in settings, organise and transcoder dialogs
  + Improved Tidal error handling and automatic login
  + Improved Tidal search to handle duplicate albums
  + Notify collection backend about renamed files when organising files
  + Added more background image options
  + Removed API Seeds lyrics provider (require payment)
  + Added group by format
  + Fixed gstreamer leaks
* Sat Jan 26 2019 Jonas Kvinge <jonas@jkvinge.net>
- Update to version 0.5.2
  + Added error handling and message for URL handler
  + Added SingleCoreApplication secondary check
  + Fixed memory leaks in devices
  + Fixed more stability issues in devices
  + Remove remastered from album title when searching for lyrics, covers and scrobbling
  + Fixed CMake check for X11 headers
  + Enabled iLister and AFC device
  + Added saving of album cover to gpod devices
  + Fixed AAC/MP4 transcoder
  + Added log to organise error dialog
  + Added warning when enabling X11 shortcuts on Gnome, Cinnamon or KDE
  + Fixed transcoder to use filename suffixes to solve issues when copying files to iPods
  + Added option to copy album cover in organise dialog (filesystem and libgpod devices)
  + Added raise() to make sure window is on top when strawberry is started twice
* Sat Jan 12 2019 Jonas Kvinge <jonas@jkvinge.net>
- Update to version 0.5.1
  + Added scrobbler with support for Last.fm, Libre.fm and ListenBrainz
  + Fixed key up causing playback to reset
  + New improved last.fm and musicbrainz album cover providers
  + Removed Qt5Xml and liblastfm dependency
  + Replaced sha2 with QCryptographicHash
  + Fixed songs not showing up under devices
  + Removed qxt dependency
  + Replaced globalshortcuts backend for X11 and Windows
  + Made global shortcuts on X11 optional and off by default
  + Added support for Monkey's Audio
  + Fixed crashes in devices
  + Enabled transcoder and organiser in menus
  + Added transcoder for WavPack
  + Changed default group by for collection to album artist
  + Enabled organise without gstreamer
  + Added cmake USE_BUNDLE option for macOS/Windows
  + Fixed broken GSD D-Bus shortcuts backend
  + Fixed broken background image setting
  + Disabling fading when a ALSA device is selected
  + Replaced QtSingleApplication with SingleApplication
  + Fixed scroll over icon to change track feature
  + Fixed freeze when changing appearance settings
  + Made text in about dialog selectable
  + Improved manual pages
  + Fixed typos
  + Updated contributors in about
  + Added debian copyright file
  + Fixed some compile errors
- Remove unneeded libQt5Gui-private-headers-devel, Qt5Xml and liblastfm dependency
- Update description
* Wed Nov 28 2018 Jonas Kvinge <jonas@jkvinge.net>
- Update to version 0.4.2
  + Updated AppStream data file to newer specifications
  + Fixed Deezer engine to use quality setting
  + Removed unneeded dependency Qt5OpenGL
  + Removed obsolete xine warning and engine reinitialization
  + Added ALSA as optional component in cmake
  + Fixed bug in playlist columns setting all visible
  + Added option to reset playlist columns
  + Fixed/Improved console logging
  + Added queue to play next option
- Removed unneeded Qt5OpenGL dependency
- Use system taglib
- Only install Appdata file on Leap 15.0 or higher
- Update description
* Sat Nov 10 2018 Jonas Kvinge <jonas@jkvinge.net>
- Add require for libQt5Sql5-sqlite
* Fri Nov  2 2018 Jonas Kvinge <jonas@jkvinge.net>
- Update to version 0.4.1
  + Fixed crash in analyzer
  + Fixed trying to use systray even if the desktop had no systray
  + Fixed Tidal login loop bug
  + Added Deezer support
  + New improved fancy tabwidget
  + Fixed bug not loading engine settings
  + Moved queue manager into tabbar for easier access
  + Fixed crash when changing appearance colors
  + Improved error handling between player and engine
  + Added setting to allow continue to the next song in the playlist based on error
  + Improved Xine engine code
  + Moved some settings
  + Updated builtin taglib
  + Added AppStream data file
  + Fixed compiling with Qt 5 versions of system QtSingleApplication and Qxt library
- Add desktop-file-validate and appstream-util validate
- Install strawberry.appdata.xml
* Sun Oct  7 2018 Jonas Kvinge <jonas@jkvinge.net>
- Build without vlc on Leap 42.3
* Sun Oct  7 2018 Jonas Kvinge <jonas@jkvinge.net>
- Fix 'Extended header atime is out of range'
* Tue Sep 25 2018 Jonas Kvinge <jonas@jkvinge.net>
- Update to version 0.3.3
  + Fixed search error not shown in Tidal search
  + Added URL handler for Tidal, now retrieving URL's when playing instead of when searching
  + Fixed bug in pipeline not setting url
  + Fixed bug setting wrong temporary metadata
  + Added support for both ALSA hw and plughw
  + Added option to change url stream scheme for Tidal
  + Added encoding of Tidal token in the source code
  + Added encoding of Tidal password in the configuration
  + Fixed Tidal login
* Sat Sep 15 2018 Jonas Kvinge <jonas@jkvinge.net>
- Update to 0.3.1
- Update features
* Fri Jul  6 2018 jonas@jkvinge.net
- Fix Qt 5 dependencies
* Fri Jul  6 2018 jonas@jkvinge.net
- Add back update-desktop-files
* Fri Jul  6 2018 jonas@jkvinge.net
- Remove unneeded dependency Qt5Test
- Require update-desktop-files only for version less than 1500
- Add COPYING file to %%license
* Thu Jul  5 2018 jonas@jkvinge.net
- Update to 0.2.1
* Tue Jul  3 2018 jonas@jkvinge.net
- Update spec file
* Thu Jun  7 2018 jonas@jkvinge.net
- Update to 0.1.6
* Wed May 16 2018 jonas@jkvinge.net
- Update to 0.1.5
* Fri May 11 2018 jonas@jkvinge.net
- Update to 0.1.3
* Mon May  7 2018 jonas@jkvinge.net
- Initial package.
